==> 6.8.3-0-202503201424qtwebengine-everywhere-src-6.8.3.zip: src/3rdparty/chromium/services/tracing/perfetto/system_test_utils.h <==
// Copyright 2019 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef SERVICES_TRACING_PERFETTO_SYSTEM_TEST_UTILS_H_
#define SERVICES_TRACING_PERFETTO_SYSTEM_TEST_UTILS_H_

#include <string>

#include "base/functional/callback.h"
#include "services/tracing/public/cpp/perfetto/posix_system_producer.h"

namespace base {
class ScopedTempDir;
}

namespace perfetto {
class ServiceIPCHost;
class TracingService;
namespace base {
class TaskRunner;
}
}  // namespace perfetto

namespace tracing {

class MockSystemService {
 public:
  MockSystemService(const std::string& consumer_socket,
                    const std::string& producer_socket);
  explicit MockSystemService(const base::ScopedTempDir& tmp_dir);
  MockSystemService(const base::ScopedTempDir& tmp_dir,
                    std::unique_ptr<perfetto::base::TaskRunner>);
  ~MockSystemService();

  perfetto::TracingService* GetService();
  const std::string& consumer() const;
  const std::string& producer() const;

 private:
  void StartService();

  const bool used_tmpdir_;
  absl::optional<std::string> old_tmpdir_;
  std::string consumer_;
  std::string producer_;
  std::unique_ptr<perfetto::ServiceIPCHost> service_;
  std::unique_ptr<perfetto::base::TaskRunner> task_runner_;
};

class MockPosixSystemProducer : public PosixSystemProducer {
 public:
  MockPosixSystemProducer(
      const std::string& socket,
      bool check_sdk_level = false,
      uint32_t num_data_sources = 0,
      base::OnceClosure data_source_enabled_callback = base::OnceClosure(),
      base::OnceClosure data_source_disabled_callback = base::OnceClosure(),
      bool sandbox_forbids_socket_connection = false);

  ~MockPosixSystemProducer() override;

  void StartDataSource(
      perfetto::DataSourceInstanceID id,
      const perfetto::DataSourceConfig& data_source_config) override;

  void StopDataSource(perfetto::DataSourceInstanceID id) override;

  void SetDataSourceEnabledCallback(
      base::OnceClosure data_source_enabled_callback);

  void SetDataSourceDisabledCallback(
      base::OnceClosure data_source_disabled_callback);

 protected:
  // Override for testing.
  bool SandboxForbidsSocketConnection() override;

 private:
  uint32_t num_data_sources_expected_;
  uint32_t num_data_sources_active_ = 0;
  base::OnceClosure data_source_enabled_callback_;
  base::OnceClosure data_source_disabled_callback_;
  std::unique_ptr<SystemProducer> old_producer_;
  bool sandbox_forbids_socket_connection_;
};

}  // namespace tracing

#endif  // SERVICES_TRACING_PERFETTO_SYSTEM_TEST_UTILS_H_

==> 6.9.3-0-202509261208qtwebengine-everywhere-src-6.9.3.zip: src/3rdparty/chromium/services/tracing/perfetto/system_test_utils.h <==
// Copyright 2019 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef SERVICES_TRACING_PERFETTO_SYSTEM_TEST_UTILS_H_
#define SERVICES_TRACING_PERFETTO_SYSTEM_TEST_UTILS_H_

#include <string>

#include "base/functional/callback.h"
#include "services/tracing/public/cpp/perfetto/posix_system_producer.h"

namespace base {
class ScopedTempDir;
}

namespace perfetto {
class ServiceIPCHost;
class TracingService;
namespace base {
class TaskRunner;
}
}  // namespace perfetto

namespace tracing {

class MockSystemService {
 public:
  MockSystemService(const std::string& consumer_socket,
                    const std::string& producer_socket);
  explicit MockSystemService(const base::ScopedTempDir& tmp_dir);
  MockSystemService(const base::ScopedTempDir& tmp_dir,
                    std::unique_ptr<perfetto::base::TaskRunner>);
  ~MockSystemService();

  perfetto::TracingService* GetService();
  const std::string& consumer() const;
  const std::string& producer() const;

 private:
  void StartService();

  const bool used_tmpdir_;
  std::optional<std::string> old_tmpdir_;
  std::string consumer_;
  std::string producer_;
  std::unique_ptr<perfetto::ServiceIPCHost> service_;
  std::unique_ptr<perfetto::base::TaskRunner> task_runner_;
};

class MockPosixSystemProducer : public PosixSystemProducer {
 public:
  MockPosixSystemProducer(
      const std::string& socket,
      bool check_sdk_level = false,
      uint32_t num_data_sources = 0,
      base::OnceClosure data_source_enabled_callback = base::OnceClosure(),
      base::OnceClosure data_source_disabled_callback = base::OnceClosure(),
      bool sandbox_forbids_socket_connection = false);

  ~MockPosixSystemProducer() override;

  void StartDataSource(
      perfetto::DataSourceInstanceID id,
      const perfetto::DataSourceConfig& data_source_config) override;

  void StopDataSource(perfetto::DataSourceInstanceID id) override;

  void SetDataSourceEnabledCallback(
      base::OnceClosure data_source_enabled_callback);

  void SetDataSourceDisabledCallback(
      base::OnceClosure data_source_disabled_callback);

 protected:
  // Override for testing.
  bool SandboxForbidsSocketConnection() override;

 private:
  uint32_t num_data_sources_expected_;
  uint32_t num_data_sources_active_ = 0;
  base::OnceClosure data_source_enabled_callback_;
  base::OnceClosure data_source_disabled_callback_;
  std::unique_ptr<SystemProducer> old_producer_;
  bool sandbox_forbids_socket_connection_;
};

}  // namespace tracing

#endif  // SERVICES_TRACING_PERFETTO_SYSTEM_TEST_UTILS_H_
